#!/bin/bash -e
# 
# Goal: create a small microsite in a container from this branch
# 
# Notes:
# 
# - A new container will be created each time.
# - This script should be run as root
# - Your code will be copied into the microsite

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
NAME=${MICROSITE_CONTAINER:-manpages-microsite}
SITE_PATH=/srv/manpages.ubuntu.com

if ! lxc info "$NAME" 2>/dev/null; then
	lxc launch ubuntu:xenial "$NAME"
	sleep 5
	lxc exec "$NAME" -- apt update
else
	echo "-------------------------------------------"
	echo "Found existing container: $NAME"
	echo "Hit [CTRL]-c to avoid wiping out $NAME:$SITE_PATH"
	read -p "Press enter to continue"
	echo "-------------------------------------------"
fi

lxc exec "$NAME" -- apt install -y apache2 bzr make < /dev/null
lxc exec "$NAME" -- rm -rf "$SITE_PATH"
lxc exec "$NAME" -- mkdir -p "$SITE_PATH"
tar cf - "$DIR/../" | lxc exec "$NAME" -- tar xvf - -C "$SITE_PATH"
lxc exec "$NAME" -- sh -c "cd $SITE_PATH; make deps setup-microsite-in-server manpage-repo"

echo "--------"
echo "Summary:"
echo "--------"
echo ""
lxc list "$NAME"

IP=$(lxc info "$NAME" |grep eth0: |grep -v inet6 | awk '{ print $3 }')
echo ""
echo "Site URL: http://$IP:8080"
echo " * Try searching for 'ac'"
